@@ -1,9 +1,10 @@
 /*
   Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -36,14 +37,14 @@ void FilterConvertToSieve::convert()
 {
     QString result;
     if (!mListFilters.isEmpty()) {
-        QStringList requires;
+        QStringList requiresModule;
         QString code;
         for (MailFilter *filter : qAsConst(mListFilters)) {
-            filter->generateSieveScript(requires, code);
+            filter->generateSieveScript(requiresModule, code);
             code += QLatin1Char('\n');
         }
         QString requireStr;
-        for (const QString &require : qAsConst(requires)) {
+        for (const QString &require : qAsConst(requiresModule)) {
             requireStr += QStringLiteral("require \"%1\";").arg(require);
             requireStr += QLatin1Char('\n');
         }
