@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -71,8 +72,8 @@ void FilterImporterSylpheed::parseConditions(const QDomElement &e, MailCommon::M
         }
     }
     for (QDomElement ruleFilter = e.firstChildElement();
-            !ruleFilter.isNull();
-            ruleFilter = ruleFilter.nextSiblingElement()) {
+         !ruleFilter.isNull();
+         ruleFilter = ruleFilter.nextSiblingElement()) {
         QString contentsName;
         QByteArray fieldName;
         SearchRule::Function functionName = SearchRule::FuncNone;
@@ -170,12 +171,11 @@ void FilterImporterSylpheed::parseConditions(const QDomElement &e, MailCommon::M
     }
 }
 
-void FilterImporterSylpheed::parseActions(const QDomElement &e,
-        MailCommon::MailFilter *filter)
+void FilterImporterSylpheed::parseActions(const QDomElement &e, MailCommon::MailFilter *filter)
 {
     for (QDomElement ruleFilter = e.firstChildElement();
-            !ruleFilter.isNull();
-            ruleFilter = ruleFilter.nextSiblingElement()) {
+         !ruleFilter.isNull();
+         ruleFilter = ruleFilter.nextSiblingElement()) {
         QString actionName;
         const QString nexttag = ruleFilter.tagName();
         QString value = ruleFilter.text();
@@ -251,11 +251,10 @@ void FilterImporterSylpheed::parseFilters(const QDomElement &e)
         } else {
             qCDebug(MAILCOMMON_LOG) << " timing not defined: " << attr;
         }
-
     }
     for (QDomElement ruleFilter = e.firstChildElement();
-            !ruleFilter.isNull();
-            ruleFilter = ruleFilter.nextSiblingElement()) {
+         !ruleFilter.isNull();
+         ruleFilter = ruleFilter.nextSiblingElement()) {
         const QString nexttag = ruleFilter.tagName();
         if (nexttag == QLatin1String("condition-list")) {
             parseConditions(ruleFilter, filter);
